aboutsummaryrefslogtreecommitdiff
path: root/include/xglWsiX11Ext.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/xglWsiX11Ext.h')
-rw-r--r--include/xglWsiX11Ext.h78
1 files changed, 39 insertions, 39 deletions
diff --git a/include/xglWsiX11Ext.h b/include/xglWsiX11Ext.h
index 5235758d..f7046375 100644
--- a/include/xglWsiX11Ext.h
+++ b/include/xglWsiX11Ext.h
@@ -1,36 +1,36 @@
/* IN DEVELOPMENT. DO NOT SHIP. */
-#ifndef __XGLWSIX11EXT_H__
-#define __XGLWSIX11EXT_H__
+#ifndef __VKWSIX11EXT_H__
+#define __VKWSIX11EXT_H__
#include <xcb/xcb.h>
#include <xcb/randr.h>
-#include "xgl.h"
+#include "vulkan.h"
#ifdef __cplusplus
extern "C"
{
#endif // __cplusplus
-typedef struct _XGL_WSI_X11_CONNECTION_INFO {
+typedef struct _VK_WSI_X11_CONNECTION_INFO {
xcb_connection_t* pConnection;
xcb_window_t root;
xcb_randr_provider_t provider;
-} XGL_WSI_X11_CONNECTION_INFO;
+} VK_WSI_X11_CONNECTION_INFO;
-typedef struct _XGL_WSI_X11_PRESENTABLE_IMAGE_CREATE_INFO
+typedef struct _VK_WSI_X11_PRESENTABLE_IMAGE_CREATE_INFO
{
- XGL_FORMAT format;
- XGL_FLAGS usage; // XGL_IMAGE_USAGE_FLAGS
- XGL_EXTENT2D extent;
- XGL_FLAGS flags;
-} XGL_WSI_X11_PRESENTABLE_IMAGE_CREATE_INFO;
+ VK_FORMAT format;
+ VK_FLAGS usage; // VK_IMAGE_USAGE_FLAGS
+ VK_EXTENT2D extent;
+ VK_FLAGS flags;
+} VK_WSI_X11_PRESENTABLE_IMAGE_CREATE_INFO;
-typedef struct _XGL_WSI_X11_PRESENT_INFO
+typedef struct _VK_WSI_X11_PRESENT_INFO
{
/* which window to present to */
xcb_window_t destWindow;
- XGL_IMAGE srcImage;
+ VK_IMAGE srcImage;
/**
* After the command buffers in the queue have been completed, if the MSC
@@ -49,7 +49,7 @@ typedef struct _XGL_WSI_X11_PRESENT_INFO
* }
*
* In other words, either set \p target_msc to an absolute value (require
* xglWsiX11GetMSC(), potentially a round-trip to the server, to get the
* current MSC first), or set \p target_msc to zero and set a "swap
* interval".
*
@@ -78,66 +78,66 @@ typedef struct _XGL_WSI_X11_PRESENT_INFO
* be flipped to.
*/
bool32_t flip;
-} XGL_WSI_X11_PRESENT_INFO;
+} VK_WSI_X11_PRESENT_INFO;
-typedef XGL_RESULT (XGLAPI *xglWsiX11AssociateConnectionType)(XGL_PHYSICAL_GPU gpu, const XGL_WSI_X11_CONNECTION_INFO* pConnectionInfo);
-typedef XGL_RESULT (XGLAPI *xglWsiX11GetMSCType)(XGL_DEVICE device, xcb_window_t window, xcb_randr_crtc_t crtc, uint64_t* pMsc);
-typedef XGL_RESULT (XGLAPI *xglWsiX11CreatePresentableImageType)(XGL_DEVICE device, const XGL_WSI_X11_PRESENTABLE_IMAGE_CREATE_INFO* pCreateInfo, XGL_IMAGE* pImage, XGL_GPU_MEMORY* pMem);
-typedef XGL_RESULT (XGLAPI *xglWsiX11QueuePresentType)(XGL_QUEUE queue, const XGL_WSI_X11_PRESENT_INFO* pPresentInfo, XGL_FENCE fence);
+typedef VK_RESULT (VKAPI *vkWsiX11AssociateConnectionType)(VK_PHYSICAL_GPU gpu, const VK_WSI_X11_CONNECTION_INFO* pConnectionInfo);
+typedef VK_RESULT (VKAPI *vkWsiX11GetMSCType)(VK_DEVICE device, xcb_window_t window, xcb_randr_crtc_t crtc, uint64_t* pMsc);
+typedef VK_RESULT (VKAPI *vkWsiX11CreatePresentableImageType)(VK_DEVICE device, const VK_WSI_X11_PRESENTABLE_IMAGE_CREATE_INFO* pCreateInfo, VK_IMAGE* pImage, VK_GPU_MEMORY* pMem);
+typedef VK_RESULT (VKAPI *vkWsiX11QueuePresentType)(VK_QUEUE queue, const VK_WSI_X11_PRESENT_INFO* pPresentInfo, VK_FENCE fence);
/**
* Associate an X11 connection with a GPU. This should be done before device
* creation. If the device is already created,
- * XGL_ERROR_DEVICE_ALREADY_CREATED is returned.
+ * VK_ERROR_DEVICE_ALREADY_CREATED is returned.
*
* Truth is, given a connection, we could find the associated GPU. But
* without having a GPU as the first parameter, the loader could not find the
* dispatch table.
*
- * This function is available when xglGetExtensionSupport says "XGL_WSI_X11"
+ * This function is available when vkGetExtensionSupport says "VK_WSI_X11"
* is supported.
*/
-XGL_RESULT XGLAPI xglWsiX11AssociateConnection(
- XGL_PHYSICAL_GPU gpu,
- const XGL_WSI_X11_CONNECTION_INFO* pConnectionInfo);
+VK_RESULT VKAPI vkWsiX11AssociateConnection(
+ VK_PHYSICAL_GPU gpu,
+ const VK_WSI_X11_CONNECTION_INFO* pConnectionInfo);
/**
* Return the current MSC (Media Stream Counter, incremented for each vblank)
* of \p crtc. If crtc is \p XCB_NONE, a suitable CRTC is picked based on \p
* win.
*/
-XGL_RESULT XGLAPI xglWsiX11GetMSC(
- XGL_DEVICE device,
+VK_RESULT VKAPI vkWsiX11GetMSC(
+ VK_DEVICE device,
xcb_window_t window,
xcb_randr_crtc_t crtc,
uint64_t* pMsc);
/**
* Create an XGL_IMAGE that can be presented. An XGL_GPU_MEMORY is created
* and bound automatically. The memory returned can only be used in
- * xglQueue[Add|Remove]MemReference. Destroying the memory or binding another memory to the
+ * vkQueue[Add|Remove]MemReference. Destroying the memory or binding another memory to the
* image is not allowed.
*/
-XGL_RESULT XGLAPI xglWsiX11CreatePresentableImage(
- XGL_DEVICE device,
- const XGL_WSI_X11_PRESENTABLE_IMAGE_CREATE_INFO* pCreateInfo,
- XGL_IMAGE* pImage,
- XGL_GPU_MEMORY* pMem);
+VK_RESULT VKAPI vkWsiX11CreatePresentableImage(
+ VK_DEVICE device,
+ const VK_WSI_X11_PRESENTABLE_IMAGE_CREATE_INFO* pCreateInfo,
+ VK_IMAGE* pImage,
+ VK_GPU_MEMORY* pMem);
/**
* Present an image to an X11 window. The presentation always occurs after
* the command buffers in the queue have been completed, subject to other
* parameters specified in XGL_WSI_X11_PRESENT_INFO.
*
* Fence is reached when the presentation occurs.
*/
-XGL_RESULT XGLAPI xglWsiX11QueuePresent(
- XGL_QUEUE queue,
- const XGL_WSI_X11_PRESENT_INFO* pPresentInfo,
- XGL_FENCE fence);
+VK_RESULT VKAPI vkWsiX11QueuePresent(
+ VK_QUEUE queue,
+ const VK_WSI_X11_PRESENT_INFO* pPresentInfo,
+ VK_FENCE fence);
#ifdef __cplusplus
} // extern "C"
#endif // __cplusplus
-#endif // __XGLWSIX11EXT_H__
+#endif // __VKWSIX11EXT_H__
@@ -49,7 +49,7 @@ typedef struct _XGL_WSI_X11_PRESENT_INFO
*
* In other words, either set \p target_msc to an absolute value (require
- * xglWsiX11GetMSC(), potentially a round-trip to the server, to get the
+ * vkWsiX11GetMSC(), potentially a round-trip to the server, to get the
* current MSC first), or set \p target_msc to zero and set a "swap
* interval".
@@ -78,66 +78,66 @@ typedef struct _XGL_WSI_X11_PRESENT_INFO
uint64_t* pMsc);
/**
- * Create an XGL_IMAGE that can be presented. An XGL_GPU_MEMORY is created
+ * Create an VK_IMAGE that can be presented. An VK_GPU_MEMORY is created
* and bound automatically. The memory returned can only be used in
@@ -78,66 +78,66 @@ typedef struct _XGL_WSI_X11_PRESENT_INFO
* Present an image to an X11 window. The presentation always occurs after
* the command buffers in the queue have been completed, subject to other
- * parameters specified in XGL_WSI_X11_PRESENT_INFO.
+ * parameters specified in VK_WSI_X11_PRESENT_INFO.
*
* Fence is reached when the presentation occurs.